pub enum UserRequest {
Config,
Block(BlockHash),
UtreexoProof(BlockHash),
MempoolTransaction(Txid),
GetPeerInfo,
GetConnectionCount,
Add((IpAddr, u16, bool)),
Remove((IpAddr, u16)),
Onetry((IpAddr, u16, bool)),
Disconnect((IpAddr, u16)),
Ping,
SendTransaction(Transaction),
}Expand description
A request that can be made to the node.
While the node is running, consumers may want to request some useful data, like block data, mempool transactions or tell the node to connect with some given peers. This struct represents all the possible requests that can be made to the node as well as the data that needs to be sent along with the request.
Variants
Config
Request the UtreexoNodeConfig of the node.
Block(BlockHash)
Get a block by its hash.
This will cause network requests to be made to fetch the block data.
UtreexoProof(BlockHash)
Get the Utreexo proof and LeafData for a block by its hash.
MempoolTransaction(Txid)
Get an unconfirmed transaction from the mempool by its ID.
GetPeerInfo
Return information about all connected peers.
GetConnectionCount
Return the number of connected peers.
Add((IpAddr, u16, bool))
Add a peer to the node’s peer list.
This function will add this peer to a special list of peers such that, if we lose the connection, we will keep trying to connect to it until we succeed.
Remove((IpAddr, u16))
Removes a node from the node’s peer list.
This function will remove a node that was added with AddNode::Add. This will not
disconnect the peer, but if it disconnects, it will not be reconnected again.
Onetry((IpAddr, u16, bool))
Attempts to connect to a peer once.
Different from AddNode::Add, this function will try to connect to the peer once, but
will not add it to the node’s added peers list.
Disconnect((IpAddr, u16))
Attempt to disconnect from a peer.
Ping
Ping all connected peers to check if they are alive.
SendTransaction(Transaction)
Adds a transaction to mempool and advertises it